==> qtjambi-quick-debuginfo-linux-x64-6.5.8.jar: sources/QtJambiQuick/QSGOpacityNode_shell.cpp <==
#include "QSGOpacityNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGOpacityNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGOpacityNode")
    QSGOpacityNode *_ptr = reinterpret_cast<QSGOpacityNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGOpacityNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGOpacityNode_shell) ); }

jmethodID QSGOpacityNode_oshell::__shell_javaMethod(int pos) const { return QSGOpacityNode_shell::__shell()->javaMethod(typeid(QSGOpacityNode), pos); }

// emitting (writeShellDestructor)
QSGOpacityNode_shell::~QSGOpacityNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGOpacityNode::~QSGOpacityNode()", this)
    QSGOpacityNode_shell::__shell()->destructed(typeid(QSGOpacityNode));
}

// emitting (writeShellConstructor)
QSGOpacityNode_shell::QSGOpacityNode_shell()
    : QSGOpacityNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGOpacityNode::QSGOpacityNode_shell()", this)
    QSGOpacityNode_shell::__shell()->constructed(typeid(QSGOpacityNode));
}

void QSGOpacityNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGOpacityNode_shell*>(ptr)->QSGOpacityNode_shell::__shell()->tryDeleteShell(typeid(QSGOpacityNode));
}

void QSGOpacityNode_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGOpacityNode_oshell*>(ptr)->QSGOpacityNode_oshell::__shell()->tryDeleteShell(typeid(QSGOpacityNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGOpacityNode_oshell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGOpacityNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGOpacityNode_shell::__shell()->warnForMethod("QSGOpacityNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGOpacityNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGOpacityNode::isSubtreeBlocked();
        }
    }else{
        return QSGOpacityNode::isSubtreeBlocked();
    }
}

void QSGOpacityNode_oshell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QSGOpacityNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QSGOpacityNode_shell::__shell()->warnForMethod("QSGOpacityNode::preprocess()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGOpacityNode::preprocess()");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QSGOpacityNode_access::__qt_isSubtreeBlocked_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        bool __qt_return_value = QSGOpacityNode::isSubtreeBlocked();
        return jboolean(__qt_return_value);
    } else {
        bool __qt_return_value = isSubtreeBlocked();
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QSGOpacityNode()
void __qt_construct_QSGOpacityNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGOpacityNode()")
    Q_UNUSED(__java_arguments)
    QSGOpacityNode *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QSGOpacityNode_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QSGOpacityNode_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSGOpacityNode::QSGOpacityNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_initialize_1native__Lio_qt_quick_QSGOpacityNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGOpacityNode::QSGOpacityNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGOpacityNode, sizeof(QSGOpacityNode_shell), typeid(QSGOpacityNode), 0, true, &deleter_QSGOpacityNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGOpacityNode_shell
void __qt_destruct_QSGOpacityNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGOpacityNode")
    reinterpret_cast<QSGOpacityNode_shell*>(ptr)->~QSGOpacityNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGOpacityNode::combinedOpacity()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_combinedOpacity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::combinedOpacity()const", __this_nativeId)
        qreal __qt_return_value = __qt_this->combinedOpacity();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGOpacityNode::opacity()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_opacity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::opacity()const", __this_nativeId)
        qreal __qt_return_value = __qt_this->opacity();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGOpacityNode::setCombinedOpacity(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_setCombinedOpacity_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble opacity0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::setCombinedOpacity(qreal)", __this_nativeId)
        __qt_this->setCombinedOpacity(static_cast<qreal>(opacity0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGOpacityNode::setOpacity(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_setOpacity_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble opacity0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::setOpacity(qreal)", __this_nativeId)
        __qt_this->setOpacity(static_cast<qreal>(opacity0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGOpacityNode::isSubtreeBlocked()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_isSubtreeBlocked_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::isSubtreeBlocked()const", __this_nativeId)
        __java_return_value = static_cast<const QSGOpacityNode_access*>(__qt_this)->__qt_isSubtreeBlocked_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGOpacityNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGOpacityNode>("QSGOpacityNode", "io/qt/quick/QSGOpacityNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGOpacityNode, {
        ConstructorInfo(&__qt_construct_QSGOpacityNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGOpacityNode);
    registerSizeOfShell(typeId, sizeof(QSGOpacityNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGOpacityNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiQuick/QSGOpacityNode_shell.cpp <==
#include "QSGOpacityNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGOpacityNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGOpacityNode")
    QSGOpacityNode *_ptr = reinterpret_cast<QSGOpacityNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGOpacityNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGOpacityNode_shell) ); }

jmethodID QSGOpacityNode_shell::__shell_javaMethod(int pos) const { return QSGOpacityNode_shell::__shell()->javaMethod(typeid(QSGOpacityNode), pos); }

// emitting (writeShellConstructor)
QSGOpacityNode_shell::QSGOpacityNode_shell()
    : QSGOpacityNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGOpacityNode::QSGOpacityNode_shell()", QSGOpacityNode_shell::__shell())
    QSGOpacityNode_shell::__shell()->constructed(typeid(QSGOpacityNode));
}

// emitting (writeShellDestructor)
QSGOpacityNode_shell::~QSGOpacityNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGOpacityNode::~QSGOpacityNode()", QSGOpacityNode_shell::__shell())
    QSGOpacityNode_shell::__shell()->destructed(typeid(QSGOpacityNode));
}

void QSGOpacityNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGOpacityNode_shell*>(ptr)->QSGOpacityNode_shell::__shell()->tryDeleteShell(typeid(QSGOpacityNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGOpacityNode_shell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGOpacityNode::isSubtreeBlocked()const", QSGOpacityNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGOpacityNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGOpacityNode_shell::__shell()->warnForMethod("QSGOpacityNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGOpacityNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGOpacityNode::isSubtreeBlocked();
        }
    }else{
        return QSGOpacityNode::isSubtreeBlocked();
    }
}

void QSGOpacityNode_shell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGOpacityNode::", QSGOpacityNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGOpacityNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGOpacityNode_shell::__shell()->warnForMethod("QSGOpacityNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGOpacityNode::");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QSGOpacityNode_access::__qt_isSubtreeBlocked_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        bool __qt_return_value = QSGOpacityNode::isSubtreeBlocked();
        return jboolean(__qt_return_value);
    } else {
        bool __qt_return_value = isSubtreeBlocked();
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QSGOpacityNode()
void __qt_construct_QSGOpacityNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGOpacityNode()")
    Q_UNUSED(__java_arguments)
    QSGOpacityNode *__qt_this = new(__qtjambi_ptr) QSGOpacityNode_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGOpacityNode::QSGOpacityNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_initialize_1native__Lio_qt_quick_QSGOpacityNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGOpacityNode::QSGOpacityNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGOpacityNode, sizeof(QSGOpacityNode_shell), typeid(QSGOpacityNode), true, &deleter_QSGOpacityNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGOpacityNode_shell
void __qt_destruct_QSGOpacityNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGOpacityNode")
    reinterpret_cast<QSGOpacityNode_shell*>(ptr)->~QSGOpacityNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGOpacityNode::combinedOpacity()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_combinedOpacity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::combinedOpacity()const", __qt_this)
        qreal __qt_return_value = __qt_this->combinedOpacity();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGOpacityNode::opacity()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_opacity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::opacity()const", __qt_this)
        qreal __qt_return_value = __qt_this->opacity();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGOpacityNode::setCombinedOpacity(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_setCombinedOpacity_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble opacity0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::setCombinedOpacity(qreal)", __qt_this)
        __qt_this->setCombinedOpacity(static_cast<qreal>(opacity0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGOpacityNode::setOpacity(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_setOpacity_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble opacity0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::setOpacity(qreal)", __qt_this)
        __qt_this->setOpacity(static_cast<qreal>(opacity0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGOpacityNode::isSubtreeBlocked()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_isSubtreeBlocked_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGOpacityNode::isSubtreeBlocked()const", __qt_this)
        __java_return_value = static_cast<const QSGOpacityNode_access*>(__qt_this)->__qt_isSubtreeBlocked_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGOpacityNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGOpacityNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGOpacityNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGOpacityNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGOpacityNode>("QSGOpacityNode", "io/qt/quick/QSGOpacityNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGOpacityNode, {
        ConstructorInfo(&__qt_construct_QSGOpacityNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGOpacityNode);
    registerSizeOfShell(typeId, sizeof(QSGOpacityNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGOpacityNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
